package com.usky.dxtop.service.listener;

import com.alibaba.fastjson.JSONObject;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.model.MsgLog;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.config.rabbitmq.cartget.CartGetProduceConfig;
import com.usky.dxtop.service.emun.MsgLogStatus;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.nio.charset.StandardCharsets;

/**
 * 卡余额
 * @author yq
 * @date 2021/11/29 16:35
 */
@Slf4j
@Component
public class CartGetMqListener {

    @Autowired
    private MsgLogService msgLogService;
    @Transactional(rollbackFor = Exception.class)
    @RabbitListener(queues = CartGetProduceConfig.NAME, containerFactory = CartGetProduceConfig.LISTENER)
    public void dealDeclareMessage(Message message) {
        try {
            //消息类型
            String s = new String(message.getBody(), StandardCharsets.UTF_8);
            JSONObject jsonObject = JSONObject.parseObject(s);
            Long msgId = Long.parseLong(jsonObject.get("seq").toString());
            MsgLog msgLog = msgLogService.getById(msgId);
            if (msgLogService.isRepetition(msgLog)){
                msgLog.setConsequence(s);
                msgLog.setMsgFlag(MsgLogStatus.CONSUMER_SUCCESS.getCode());
                msgLogService.updateById(msgLog);
            }
        } catch (Exception e) {
            log.info("charge_trans_produce"+"异常信息：" + e.getMessage());
            throw new CustomException(e.getMessage());
        }
    }
}
