package com.usky.dxtop.service.listener;

import com.alibaba.fastjson.JSONObject;
import com.usky.dxtop.common.exception.CustomException;
import com.usky.dxtop.model.MsgLog;
import com.usky.dxtop.model.Order;
import com.usky.dxtop.service.MsgLogService;
import com.usky.dxtop.service.OrderService;
import com.usky.dxtop.service.config.rabbitmq.charge.ChargeProduceConfig;
import com.usky.dxtop.service.emun.MsgLogStatus;
import com.usky.dxtop.service.emun.OrderStatus;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.nio.charset.StandardCharsets;

/**
 * @author yq
 * @date 2021/9/15 13:56
 */
@Slf4j
@Component
public class ChargeMqListener {

    @Autowired
    private OrderService orderService;
    @Autowired
    private MsgLogService msgLogService;
    @Transactional(rollbackFor = Exception.class)
    @RabbitListener(queues = ChargeProduceConfig.NAME, containerFactory = ChargeProduceConfig.LISTENER)
    public void dealDeclareMessage(Message message) {
        try {
            //消息类型
            String routingKey = message.getMessageProperties().getReceivedRoutingKey();
            log.info(routingKey);
            String s = new String(message.getBody(), StandardCharsets.UTF_8);
            log.info("charge_trans_produce:接受到的消息"+s);
            JSONObject jsonObject = JSONObject.parseObject(s);
            Long msgId = Long.parseLong(jsonObject.get("seq").toString());
            MsgLog msgLog = msgLogService.getById(msgId);
            if (msgLogService.isRepetition(msgLog)){
                Order order = new Order();
                order.setId(msgLog.getBusinessId());
                if ("1".equals(jsonObject.get("code"))) {
                    order.setOrderFlag(OrderStatus.COMPLETE.getCode());
                }else {
                    order.setOrderFlag(OrderStatus.PAYMENT_ERROR_DEBIT.getCode());
                }
                orderService.updateById(order);
                msgLog.setConsequence(s);
                msgLog.setMsgFlag(MsgLogStatus.CONSUMER_SUCCESS.getCode());
                msgLogService.updateById(msgLog);
            }
        } catch (Exception e) {
            log.info("charge_trans_produce"+"异常信息：" + e.getMessage());
            throw new CustomException(e.getMessage());
        }
    }
}
